-----------------------------------------------------------------------------------------------------------
--[[
	NaW - Demo Test File
    Copyright (C) 2011.
	Written by Roland Yonaba - E-mail: roland[dot]yonaba[at]gmail[dot]com
	NaW is a basic Real Time Strategy written in pure Lua using Lve2d.
	
	Credits to : Pierrodu50 ( for sprites )
				 Pleaser ( for logos design )
--]]
-----------------------------------------------------------------------------------------------------------

local require = require
local print = print
local randomseed = math.randomseed
local GLOBALS, Cursor, Map, Resources, Units

-- Loading callback
function love.load()
	print('Reading Constants...')
	CONSTANTS = require 'Scripts/Constants'	    
	print('Enabling Mouse...')
	Cursor = require 'Scripts/Cursor'            
	Cursor()                                      
	print('Randomization...')
	randomseed(os.time())                    
	print('Loading Map...')
	Map = require 'Scripts/Map'                   
	print('Creating Map...')
	Map(800*6,600*6,30,30)                       
	print('Enabling Map Background...')
	Map:setBackground 'Images/Resources/Map.png' 
	print('Enabling Resources...')
	Resources = require 'Scripts/Resources'       
	print('Creating Resources...')
	Resources(Map,50,150,25,15)                   
	print('Setting Internal Font Size...')
	love.graphics.setFont(10)                    
	print('Setting Filesystem')
	love.filesystem.setIdentity("NaW/")
		if not love.filesystem.exists('Maps') then	
		love.filesystem.mkdir("Maps/")	
		end
	print('Writing collision Map')
	Map:writeCMap()
	print('Initializing Units Manager')
	Units = require 'Scripts/Units'
	print('Done Successfully!')
end



-- Updating callback
function love.update(dt)	
	Map:update(Cursor,dt*1000/3)                         
end

-- Drawing callback
function love.draw()
	
	Map:draw()							       
	Resources:drawAll(Map,Cursor)               
	Map.minimap:draw(Map,Cursor,{items = Resources.all, color = 'GREEN'})
	--Unit:drawAll()
	Cursor:draw(Map.minimap)                         
	
	love.graphics.setColor(CONSTANTS.COLORS.WHITE)  
	love.graphics.print('MapX '..Map.mapX,10,10)
	love.graphics.print('MapY '..Map.mapY,10,20)	
	love.graphics.print('CursorX '..Cursor.x,10,30)	
	love.graphics.print('CursorY '..Cursor.y,10,40)	
	love.graphics.print('Resources '..#Resources.all..' generated!',10,50)		
	love.graphics.print('FPS : '..love.timer.getFPS(),10,560)
	
end


-- Mousepressed callback
function love.mousepressed(x,y,button)
	Cursor:onButtonPressed(x,y,button,Map.minimap)
	Resources:deselectAll(button)

end

-- Mousereleased callback
function love.mousereleased(x,y,button)
	Cursor:onButtonReleased(x,y,button)
end

-- Exit callback
function love.quit()

end

